@@ -6,22 +6,20 @@ from __future__ import print_function, absolute_import, division, unicode_litera
 # ruamel.base installed __init__.py, and thus a new version should
 # be installed at some point
 
-from typing import Dict, Any  # NOQA
+if False:  # MYPY
+    from typing import Dict, Any  # NOQA
 
 _package_data = dict(
     full_package_name='ruamel.yaml',
-    version_info=(0, 14, 4),
-    __version__='0.14.4',
+    version_info=(0, 14, 10),
+    __version__='0.14.10',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     description='ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation of comments, seq/map flow style, and map key order',  # NOQA
     entry_points=None,
     install_requires=dict(
         any=[],
-        py33=['typing'],
-        py34=['typing'],
-        py27=['ruamel.ordereddict', 'typing'],
-        pypy=['typing'],
+        py27=['ruamel.ordereddict'],
     ),
     ext_modules=[dict(
             name='_ruamel_yaml',
